@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# flake8: noqa
 
 """
 gspread
@@ -9,22 +9,23 @@ Google Spreadsheets client library.
 """
 
 
-__version__ = '4.0.1'
-__author__ = 'Anton Burnashev'
+__version__ = "5.0.0"
+__author__ = "Anton Burnashev"
 
 
 from .auth import oauth, service_account, service_account_from_dict
+from .cell import Cell
 from .client import Client
-from .models import Spreadsheet, Worksheet, Cell
-
 from .exceptions import (
-    GSpreadException,
-    SpreadsheetNotFound,
-    NoValidUrlKeyFound,
-    IncorrectCellLabel,
-    WorksheetNotFound,
     CellNotFound,
+    GSpreadException,
+    IncorrectCellLabel,
+    NoValidUrlKeyFound,
+    SpreadsheetNotFound,
+    WorksheetNotFound,
 )
+from .spreadsheet import Spreadsheet
+from .worksheet import Worksheet
 
 
 def authorize(credentials, client_class=Client):
