@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 gspread.auth
 ~~~~~~~~~~~~
@@ -9,27 +7,26 @@ Simple authentication with OAuth.
 """
 
 import os
+
 from google.oauth2.credentials import Credentials
-from google.oauth2.service_account import (
-    Credentials as ServiceAccountCredentials,
-)
+from google.oauth2.service_account import Credentials as ServiceAccountCredentials
 from google_auth_oauthlib.flow import InstalledAppFlow
 
 from .client import Client
 
 DEFAULT_SCOPES = [
-    'https://www.googleapis.com/auth/spreadsheets',
-    'https://www.googleapis.com/auth/drive',
+    "https://www.googleapis.com/auth/spreadsheets",
+    "https://www.googleapis.com/auth/drive",
 ]
 
 READONLY_SCOPES = [
-    'https://www.googleapis.com/auth/spreadsheets.readonly',
-    'https://www.googleapis.com/auth/drive.readonly',
+    "https://www.googleapis.com/auth/spreadsheets.readonly",
+    "https://www.googleapis.com/auth/drive.readonly",
 ]
 
 
-def get_config_dir(config_dir_name='gspread', os_is_windows=os.name == 'nt'):
-    """Construct a config dir path.
+def get_config_dir(config_dir_name="gspread", os_is_windows=os.name == "nt"):
+    r"""Construct a config dir path.
 
     By default:
         * `%APPDATA%\gspread` on Windows
@@ -39,21 +36,17 @@ def get_config_dir(config_dir_name='gspread', os_is_windows=os.name == 'nt'):
     if os_is_windows:
         return os.path.join(os.environ["APPDATA"], config_dir_name)
     else:
-        return os.path.join(
-            os.path.expanduser('~'), '.config', config_dir_name
-        )
+        return os.path.join(os.path.expanduser("~"), ".config", config_dir_name)
 
 
 DEFAULT_CONFIG_DIR = get_config_dir()
 
-DEFAULT_CREDENTIALS_FILENAME = os.path.join(
-    DEFAULT_CONFIG_DIR, 'credentials.json'
-)
+DEFAULT_CREDENTIALS_FILENAME = os.path.join(DEFAULT_CONFIG_DIR, "credentials.json")
 DEFAULT_AUTHORIZED_USER_FILENAME = os.path.join(
-    DEFAULT_CONFIG_DIR, 'authorized_user.json'
+    DEFAULT_CONFIG_DIR, "authorized_user.json"
 )
 DEFAULT_SERVICE_ACCOUNT_FILENAME = os.path.join(
-    DEFAULT_CONFIG_DIR, 'service_account.json'
+    DEFAULT_CONFIG_DIR, "service_account.json"
 )
 
 
@@ -90,10 +83,9 @@ def load_credentials(filename=DEFAULT_AUTHORIZED_USER_FILENAME):
     return None
 
 
-def store_credentials(
-    creds, filename=DEFAULT_AUTHORIZED_USER_FILENAME, strip='token'
-):
-    with open(filename, 'w') as f:
+def store_credentials(creds, filename=DEFAULT_AUTHORIZED_USER_FILENAME, strip="token"):
+    os.makedirs(os.path.dirname(filename), exist_ok=True)
+    with open(filename, "w") as f:
         f.write(creds.to_json(strip))
 
 
@@ -103,7 +95,7 @@ def oauth(
     credentials_filename=DEFAULT_CREDENTIALS_FILENAME,
     authorized_user_filename=DEFAULT_AUTHORIZED_USER_FILENAME,
 ):
-    """Authenticate with OAuth Client ID.
+    r"""Authenticate with OAuth Client ID.
 
     By default this function will use the local server strategy and open
     the authorization URL in the user’s browser::
@@ -170,9 +162,7 @@ def oauth(
     return client
 
 
-def service_account(
-    filename=DEFAULT_SERVICE_ACCOUNT_FILENAME, scopes=DEFAULT_SCOPES
-):
+def service_account(filename=DEFAULT_SERVICE_ACCOUNT_FILENAME, scopes=DEFAULT_SCOPES):
     """Authenticate using a service account.
 
     ``scopes`` parameter defaults to read/write scope available in
@@ -193,9 +183,7 @@ def service_account(
 
     :rtype: :class:`gspread.Client`
     """
-    creds = ServiceAccountCredentials.from_service_account_file(
-        filename, scopes=scopes
-    )
+    creds = ServiceAccountCredentials.from_service_account_file(filename, scopes=scopes)
     return Client(auth=creds)
 
 
